@@ -8,6 +8,8 @@ use warnings;
 use Carp;
 use IO::File;
 
+use Fcntl qw(:DEFAULT :flock);
+
 use Munin::Common::Defaults;
 use Munin::Common::SyncDictFile;
 use Munin::Node::Logger;
@@ -104,9 +106,14 @@ sub write
 
     open my $fh , '>>', "$self->{spooldir}/munin-daemon.$service.$fmtTimestamp." . $self->{interval_size}
         or die "Unable to open spool file: $!";
+    flock($fh, LOCK_EX);
 
     print {$fh} "timestamp $timestamp\n";
-    print {$fh} "multigraph $service\n" unless $data->[0] =~ m{^multigraph};
+
+    # squash the $service name with the same rules as the munin-update when using plain TCP
+    # Closes D:710529
+    my $service_squashed = $service; $service_squashed =~ tr/.:/__/;
+    print {$fh} "multigraph $service_squashed\n" unless $data->[0] =~ m{^multigraph};
 
     foreach my $line (@$data) {
         # Ignore blank lines and "."-ones.
